/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "syncdaemon-share-info.h"

G_DEFINE_TYPE(SyncdaemonShareInfo, syncdaemon_share_info, G_TYPE_OBJECT)

struct _SyncdaemonShareInfoPrivate {
	gboolean accepted;
};

static void
syncdaemon_share_info_finalize (GObject *object)
{
	SyncdaemonShareInfo *sinfo = SYNCDAEMON_SHARE_INFO (object);

	if (sinfo->priv != NULL) {
		g_free (sinfo->priv);
	}

	G_OBJECT_CLASS (syncdaemon_share_info_parent_class)->finalize (object);
}

static void
syncdaemon_share_info_class_init (SyncdaemonShareInfoClass *klass)
{
	GObjectClass *object_class = G_OBJECT_CLASS (klass);

	object_class->finalize = syncdaemon_share_info_finalize;
}

static void
syncdaemon_share_info_init (SyncdaemonShareInfo *sinfo)
{
	sinfo->priv = g_new0 (SyncdaemonShareInfoPrivate, 1);
}

/**
 * syncdaemon_share_info_new:
 */
SyncdaemonShareInfo *
syncdaemon_share_info_new (void)
{
	return g_object_new (SYNCDAEMON_TYPE_SHARE_INFO, NULL);
}

/**
 * syncdaemon_share_info_new_from_hash_table:
 */
SyncdaemonShareInfo *
syncdaemon_share_info_new_from_hash_table (GHashTable *hash)
{
	SyncdaemonShareInfo *sinfo;

	sinfo = g_object_new (SYNCDAEMON_TYPE_SHARE_INFO, NULL);
	if (hash != NULL) {
		syncdaemon_share_info_set_accepted (
			sinfo,
			g_strcmp0 (g_hash_table_lookup (hash, "accepted"), "True") == 0);
	}

	return sinfo;
}

/**
 * syncdameon_share_info_get_accepted:
 */
gboolean
syncdaemon_share_info_get_accepted (SyncdaemonShareInfo *sinfo)
{
	g_return_val_if_fail (SYNCDAEMON_IS_SHARE_INFO (sinfo), FALSE);

	return sinfo->accepted;
}

/**
 * syncdameon_share_info_set_accepted:
 */
void
syncdaemon_share_info_set_accepted (SyncdaemonShareInfo *sinfo, gboolean accepted)
{
	g_return_val_fail (SYNCDAEMON_IS_SHARE_INFO (sinfo));

	sinfo->accepted = accepted;
}
